"""188 of 349 diseases in Reactome have definitions"""

__copyright__ = "Copyright (C) 2018-2019, DV Klopfenstein. All rights reserved."
__author__ = "DV Klopfenstein"

# pylint: disable=line-too-long
DISEASE2DEFN = {
    "Alzheimer's disease": "A tauopathy that results in progressive memory loss, impaired thinking, disorientation, and changes in personality and mood starting and leads in advanced cases to a profound decline in cognitive and physical functioning and is marked histologically by the degeneration of brain neurons especially in the cerebral cortex and by the presence of neurofibrillary tangles and plaques containing beta-amyloid. It is characterized by memory lapses, confusion, emotional instability and progressive loss of mental ability.",
    "Crigler-Najjar syndrome": "A bilirubin metabolic disorder that involves a build up of bilirubin as bilirubin is not being broken down as a result of a lack or deficiency of the enzyme uridine diphosphate glycosyltransferase (UGT).",
    "Crouzon syndrome": "A craniosynostosis that involves premature fusion of certain skull bones. This early fusion prevents the skull from growing normally and affects the shape of the head and face. The disease is associated with mutations in the FGFR2 gene.",
    "Dubin-Johnson syndrome": "A bilirubin metabolic disorder that involves elevated levels of unconjugated bilirubin without elevation of liver alanine transaminase and aspartate transaminase enzymes as a result of the deficient ability of hepatocytes to secrete conjugated bilirubin into the bile.",
    "Ehlers-Danlos syndrome": "A collagen disease that is characterized by extremely flexible joints, elastic skin, and excessive bruising.",
    "Gilbert syndrome": "A bilirubin metabolic disorder that involves elevated levels of unconjugated bilirubin as bilirubin is not being conjugated as a result of reduced glucuronyltransferase activity.",
    "Hartnup disease": "An amino acid metabolic disorder that iis caused by abnormalities of the renal tubules and is characterized especially by aminoaciduria involving only monocarboxylic monoamines, a dry red scaly rash, and episodic muscular incoordination due to the effects of the disease on the cerebellum.",
    "Human immunodeficiency virus infectious disease": "A viral infectious disease that results_in destruction of immune system, leading to life-threatening opportunistic infections and cancers, has_material_basis_in Human immunodeficiency virus 1 or has_material_basis_in Human immunodeficiency virus 2, which are transmitted_by sexual contact, transmitted_by transfer of blood, semen, vaginal fluid, pre-ejaculate, or breast milk, transmitted_by congenital method, and transmitted_by contaminated needles. The virus infects helper T cells (CD4+ T cells) which are directly or indirectly destroyed, macrophages, and dendritic cells. The infection has_symptom diarrhea, has_symptom fatigue, has_symptom fever, has_symptom vaginal yeast infection, has_symptom headache, has_symptom mouth sores, has_symptom muscle aches, has_symptom sore throat, and has_symptom swollen lymph glands.",
    "Larsen syndrome": "An autosomal dominant disease that is characterized by large-joint dislocations and characteristic craniofacial abnormalities.",
    "Parkinson's disease": "A synucleinopathy that has_material_basis_in degeneration of the central nervous system that often impairs motor skills, speech, and other functions.",
    "Pfeiffer syndrome": "An acrocephalosyndactylia that has_material_basis_in mutations in the FGFR1 and FGFR2 gene which results_in premature fusion located_in skull.",
    "Prinzmetal angina": "A coronary artery vasospasm characterized by spasms of the coronary arteries that occur while at rest, generally late at night or early in the morning, resulting in severe chest pain with preserved exercise capacity.",
    "Rett syndrome": "A pervasive developmental disease that is characterized by normal early growth and development followed by a slowing of development, loss of purposeful use of the hands, distinctive hand movements, slowed brain and head growth, problems with walking, seizures, and intellectual disability.",
    "X-linked hypophosphatemia": "A metal metabolism disorder that results from the inactivation of hormone-like substances (phosphatonins) that promote phosphate excretion which has_material_basis_in a X-linked mutation in the PHEX gene.",
    "aceruloplasminemia": "An iron metabolism disease that has_material_basis_in a mutation in the ceruloplasmin gene characterized by progressive neurodegeneration of the retina and basal ganglia and diabetes mellitus.",
    "achondrogenesis type IB": "An achondrogenesis that has_material_basis_in mutation in the SLC26A2 gene which results_in umbilical or inguinal hernia and a prominent rounded abdomen.",
    "achondroplasia": "An osteochondrodysplasia that results_in dwarfism which has_material_basis_in abnormal ossification of cartilage in located_in long bone.",
    "acquired metabolic disease": "A disease of metabolism that has _material_basis_in enzyme deficiency or accumulation of enzymes or toxins which interfere with normal function due to an endocrine organ disease, organ malfunction, inadequate intake, dietary deficiency, or malabsorption.",
    "acrocephalosyndactylia": "A synostosis that results_in craniosynostosis and syndactyly.",
    "adrenal gland cancer": "An endocrine gland cancer located_in the adrenal glands which are located above the kidneys.",
    "adrenal gland disease": "An endocrine system disease that is located_in the adrenal gland.",
    "adrenoleukodystrophy": "A leukodystrophy that disrupts the breakdown of very-long-chain fatty acids resulting in progressive brain damage, failure of the adrenal glands and eventually death.",
    "amino acid metabolic disorder": "An inherited metabolic disorders which impair the synthesis and degradation of amino acids.",
    "anemia": "A hematopoietic system disease that is characterized by a decrease in the normal number of red blood cells.",
    "anthrax disease": "A primary bacterial infectious disease that results_in infection located_in skin, located_in lung lymph nodes or located_in gastrointestinal tract, has_material_basis_in Bacillus anthracis, transmitted_by contact with infected animals or animal products, transmitted_by airborne spores or transmitted_by ingestion of undercooked meat from infected animals and has_symptom skin ulcer, has_symptom nausea, has_symptom poor appetite, has_symptom bloody diarrhea, has_symptom fever or has_symptom shortness of breath.",
    "anxiety disorder": "A cognitive disorder that involves an excessive, irrational dread of everyday situations.",
    "arterial tortuosity syndrome": "A connective tissue disease that is characterized by elongation and generalized tortuosity of the major arteries including the aorta.",
    "asthma": "A bronchial disease that is characterized by chronic inflammation and narrowing of the airways, which is caused by a combination of environmental and genetic factors. The disease has_symptom recurring periods of wheezing (a whistling sound while breathing), has_symptom chest tightness, has_symptom shortness of breath, has_symptom mucus production and has_symptom coughing. The symptoms appear due to a variety of triggers such as allergens, irritants, respiratory infections, weather changes, exercise, stress, reflux disease, medications, foods and emotional anxiety.",
    "astrocytoma": "A malignant glioma that is has_material_basis_in astocyte cells, a type of glial cell, located_in the cerebrum.",
    "atrial fibrillation": "A heart conduction disease that is characterized by uncoordinated electrical activity in the heart's upper chambers (the atria), which causes the heartbeat to become fast and irregular and has symptoms palpitations, weakness, fatigue, lightheadedness, dizziness, confusion, shortness of breath and chest pain.",
    "attention deficit hyperactivity disorder": "A specific developmental disorder that is characterized by co-existence of attentional problems and hyperactivity, with each behavior occurring infrequently alone and symptoms starting before seven years of age.",
    "autism spectrum disorder": "A pervasive developmental disorder that is a spectrum of psychological conditions. The disease has_symptom widespread abnormalities of social interactions and communication, has_symptom severely restricted interests and has_symptom highly repetitive behavior.",
    "autistic disorder": "An autism spectrum disorder that is characterized by symptoms across all three symptom domains (communication, social, restricted repetitive interests and behaviors), delayed language development, and symptom onset prior to age 3 years.",
    "autoimmune hypersensitivity disease": "An immune system disease that is an overactive immune response of the body against substances and tissues normally present in the body resulting from an abnormal functioning of the immune system that results in the production of antibodies or T cell directed against the host tissues.",
    "autosomal recessive disease": "An autosomal genetic disease that is characterized by the presence of two mutated copies of the gene, both of which must be present in order for the disease or trait to develop.",
    "bacterial infectious disease": "A disease by infectious agent that results_in infection, has_material_basis_in Bacteria.",
    "bile duct carcinoma": "A carcinoma that starts in the bile duct.",
    "bilirubin metabolic disorder": "An inherited metabolic disorder that involves elevated levels of bilirubin resulting from disruption of bilirubin metabolism.",
    "bladder carcinoma": "A urinary bladder cancer that arises_from tissues of the bladder.",
    "bladder disease": "A urinary system disease that is located_in the bladder.",
    "blepharospasm": "A focal dystonia that is characterized by the involuntary, forcible contraction of the muscles controlling eye blinks.",
    "bone development disease": "A bone disease that results_in abnormal growth and development located_in bone or located_in cartilage.",
    "bone disease": "A musculoskeletal system disease that affects the structure or development of bone or causes an impairment of normal bone function.",
    "botulism": "A primary bacterial infectious disease that involves intoxication caused by botulinum neurotoxins (BoNTA, B, E and F) located_in neuromuscular junction, resulting in descending muscle paralysis, has_material_basis_in Clostridium botulinum A, has_material_basis_in Clostridium botulinum B, has_material_basis_in Clostridium botulinum E and has_material_basis_in Clostridium botulinum F.",
    "breast cancer": "A thoracic cancer that originates in the mammary gland.",
    "cancer": "A disease of cellular proliferation that is malignant and primary, characterized by uncontrolled cellular proliferation, local cell invasion and metastasis.",
    "carbohydrate metabolic disorder": "An inherited metabolic disorder that affect the catabolism and anabolism of carbohydrates.",
    "carcinoma": "A cell type cancer that has_material_basis_in abnormally proliferating cells derives_from epithelial cells.",
    "cardiovascular system disease": "A disease of anatomical entity which occurs in the blood, heart, blood vessels or the lymphatic system that passes nutrients (such as amino acids and electrolytes), gases, hormones, blood cells or lymph to and from cells in the body to help fight diseases and help stabilize body temperature and pH to maintain homeostasis.",
    "central nervous system cancer": "A nervous system cancer that is located_in the central nervous system.",
    "cerebrotendinous xanthomatosis": "A xanthomatosis that is characterized by a deficiency in the production of the bile acid, chenodeoxycholic acid that has_material_basis_in autosomal recessive inheritance and results in cholestanol deposition in the brain and other tissues and with elevated levels of cholesterol in plasma.",
    "cerebrovascular disease": "An artery disease that is characterized by dysfunction of the blood vessels supplying the brain.",
    "cholangiocarcinoma": "A bile duct adenocarcinoma that has_material_basis_in bile duct epithelial cells.",
    "chondrosarcoma": "A connective tissue cancer that has_material_basis_in cells derived from transformed cells that produce cartilage.",
    "cone-rod dystrophy": "A retinal degeneration that is an inherited progressive disease that causes deterioration of the cone and rod photoreceptor cells and often results in blindness.",
    "congenital disorder of glycosylation": "A carbohydrate metabolic disorder that involves deficient or defective glycosylation of a variety of tissue proteins and/or lipids.",
    "congenital disorder of glycosylation type I": "A congenital disorder of glycosylation involve disrupted synthesis of the lipid-linked oligosaccharide precursor.",
    "congenital disorder of glycosylation type II": "A congenital disorder of glycosylation involve involve malfunctioning trimming/processing of the protein-bound oligosaccharide chain.",
    "congenital hypothyroidism": "A hypothyroidism that is present at birth.",
    "congenital muscular dystrophy": "A muscular dystrophy that is an autosomal recessive disorder present at birth, which may result in contractures, scoliosis, respiratory and swallowing difficulties, and foot deformities.",
    "congenital myasthenic syndrome": "A neuromuscular junction disease that is characterized by weakness and easy fatigability resulting from a genetic defect at the junction where the nerve stimulates muscle activity that result in muscle weakness and may affect nerve cells (presynaptic), muscle cells (postsynaptic) or the space between nerve and muscle cells (synaptic).",
    "congestive heart failure": "A heart disease that is characterized by any structural or functional cardiac disorder that impairs the ability of the heart to fill with or pump a sufficient amount of blood throughout the body.",
    "connective tissue cancer": "A musculoskeletal system cancer that is located_in connective tissue.",
    "coronary artery disease": "An artery disease that is characterized by plaque building up along the inner walls of the arteries of the heart resulting in a narrowing of the arteries and a reduced blood supply to the cardiac muscles.",
    "craniosynostosis": "A synostosis that results_in premature fusion located_in skull.",
    "cystic fibrosis": "An autosomal recessive disease that is characterized by the buildup of thick, sticky mucus that can damage many organs.",
    "cystinuria": "An amino acid metabolic disorder that involves the formation of cystine stones in the kidneys, ureter, and bladder.",
    "developmental disorder of mental health": "A disease of mental health that occur during a child&apos;s developmental period between birth and age 18 resulting in retarding of the child&apos;s psycholotgical or physical development.",
    "diastrophic dysplasia": "An osteochondrodysplasia that has_material_basis_in abnormal cartilage development due to mutations in the SLC26A2 gene which results_in short limb dwarfism.",
    "dilated cardiomyopathy": "An intrinsic cardiomyopathy that results in damage to the myocardium causing the heart to pump blood inefficiently and characterized by an enlarged heart.",
    "diphtheria": "A primary bacterial infectious disease that is characterized by sore throat, low fever, and an adherent membrane (a pseudomembrane) on the tonsils, pharynx, and/or nasal cavity. A milder form of diphtheria can be restricted to the skin. It is caused by Corynebacterium diphtheriae, an aerobic Gram-positive bacterium. Diphtheria toxin spreads through the bloodstream and can lead to potentially life-threatening complications that affect other organs of the body, such as the heart and kidneys.",
    "disease": "A disease is a disposition (i) to undergo pathological processes that (ii) exists in an organism because of one or more disorders in that organism.",
    "disease by infectious agent": "A disease that is the consequence of the presence of pathogenic microbial agents, including pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and aberrant proteins known as prions.",
    "disease of mental health": "A disease that involves a psychological or behavioral pattern generally associated with subjective distress or disability that occurs in an individual, and which are not a part of normal development or culture.",
    "disease of metabolism": "A disease that involving errors in metabolic processes of building or degradation of molecules.",
    "distal arthrogryposis": "A muscle tissue disease characterized_by congenital joint contractures of hand and feet.",
    "dysentery": "An intestinal infectious disease that involves inflammation of the intestines, especially colon, due to chemical irritants, bacteria, protozoa, or parasitic worms, which results in severe diarrhea with passage of mucus and blood.",
    "epilepsy syndrome": "A brain disease that is characterized by the occurrance of at least two unprovoked seizures resulting from a persistent epileptogenic abnormality of the brain that is able to spontaneously generate paroxysmal activity and typically manifested by sudden brief episodes of altered or diminished consciousness, involuntary movements, or convulsions.",
    "esophageal carcinoma": "A esophageal cancer that is located_in the esophagus.",
    "eye disease": "An eye and adnexa disease that is located_in the eye.",
    "familial adenomatous polyposis": "An autosomal dominant disease that is has material basis in mutations in the APC gene and involves formation of numerous polyps in the epithelium of the large intestine which are initially benign and later transform into colon cancer.",
    "familial atrial fibrillation": "An atrial fibrillation that has_material_basis_in autosomal dominant inheritance of the familial atrial fibrillation (ATFB) genes.",
    "galactokinase deficiency": "A galactosemia that involves an accumulation of galactose and galactitol secondary to the decreased conversion of galactose to galactose-1-phosphate by galactokinase.",
    "galactosemia": "A carbohydrate metabolic disorder that involves a defect in galactose metabolism resulting in toxic levels of galactose 1-phosphate in various tissues.",
    "gallbladder carcinoma": "A carcinoma that is located_in the tissues of the gallbladder.",
    "gastric adenocarcinoma": "A stomach carcinoma that derives_from epithelial cells of glandular origin.",
    "glioblastoma multiforme": "An astrocytoma characterized by the presence of small areas of necrotizing tissue that is surrounded by anaplastic cells as well as the presence of hyperplastic blood vessels, and that has_material_basis_in abnormally proliferating cells derives_from multiple cell types including astrocytes and oligondroctyes.",
    "glycogen storage disease": "A carbohydrate metabolic disease that has_material_basis_in enzymes deficiencies necessary in the processing of glycogen synthesis or breakdown within muscles, liver, and other cell types.",
    "glycogen storage disease I": "A glycogen storage disease that has_material_basis_in deficiency of the glucose-6-phosphatase enzyme which impairs the ability of the liver to produce free glucose from glycogen and from gluconeogenesis and is characterized by accumulation of glycogen and fat in the liver and kidneys, resulting in hepatomegaly and renomegaly.",
    "glycogen storage disease II": "A glycogen storage disease that has_material_basis_in deficiency of the lysosomal acid alpha-glucosidase enzyme resulting in damage to muscle and nerve cells due to an accumulation of glycogen in the lysosome.",
    "goiter": "A thyroid gland disease that involves an abnormal enlargement of the thyroid gland.",
    "heart conduction disease": "A cardiovascular system disease that involves the heart's electrical conduction system.",
    "heart disease": "A cardiovascular system disease that involves the heart.",
    "hematologic cancer": "An immune system cancer located_in the hematological system that is characterized by uncontrolled cellular proliferation in blood, bone marrow and lymph nodes.",
    "hemorrhoid": "A pelvic varix disease characterized by swollen, inflamed veins around the anus or lower rectum.",
    "hereditary multiple exostoses": "An exostosis that has_material_basis_in a mutation on the genes EXT1, EXT2 and EXT3 which results_in multiple bony spurs throughout a child&apos;s growth.",
    "hereditary spastic paraplegia": "A paraplegia that is characterized by progressive stiffness and contraction (spasticity) in the lower limbs.",
    "hereditary spherocytosis": "A congenital hemolytic anemia characterized_by the production of red blood cells with a sphere shape, rather than the normal biconcave disk shape.",
    "histiocytosis": "A lymphatic system disease that is characterized by an excessive number of histiocytes.",
    "homocystinuria": "An amino acid metabolic disorder that involves an accumulation of homocysteine in the serum and an increased excretion of homocysteine in the urine.",
    "hyperinsulinemic hypoglycemia": "A carbohydrate metabolic disorder that involves low blood glucose resulting from an excess of insulin.",
    "hypermethioninemia": "An amino acid metabolic disorder that involves an excess of the amino acid methionine, in the blood. This condition can occur when methionine is not broken down properly in the body.",
    "hypertension": "An artery disease characterized by chronic elevated blood pressure in the arteries.",
    "hypochondroplasia": "An osteochondrodysplasia that has_material_basis_in mutation in the FGFR3 gene which affects ossification of cartilage and results_in short limb dwarfism.",
    "idiopathic pulmonary fibrosis": "An idiopathic interstitial pneumonia which is a distinctive type of chronic fibrosing interstitial pneumonia with thick scarring in the lung creating a honeycomb appearance. The main symptoms start insidiously as shortness of breath on exertion, cough, and diminished stamina. Other common complaints include weight loss and fatigue. The level of oxygen in the blood decreases, and the skin may take on a bluish tinge (called cyanosis) and the ends of the fingers may become thick or club-shape. In most people, symptoms worsen over a period ranging from about 6 months to several years.",
    "influenza": "A viral infectious disease that results_in infection, located_in respiratory tract, has_material_basis_in Influenzavirus A, has_material_basis_in Influenzavirus B, or has_material_basis_in Influenzavirus C, which are transmitted_by droplet spread of oronasal secretions during coughing, sneezing, or talking from an infected person. It is a highly contagious disease that affects birds and mammals and has_symptom chills, has_symptom fever, has_symptom sore throat, has_symptom runny nose, has_symptom muscle pains, has_symptom severe headache, has_symptom cough, and has_symptom weakness.",
    "inherited metabolic disorder": "A disease of metabolism that has _material_basis_in enzyme deficiency or accumulation of enzymes or toxins which interfere with normal function due to inhertied enzyme abnormality.",
    "intestinal infectious disease": "An intestinal disease that involves intestinal infection that has material basis in viruses, bacteria, fungi and parasites.",
    "kidney cancer": "A urinary system cancer that is located_in the kidney.",
    "kidney disease": "A urinary system disease that is located_in the kidney.",
    "lactic acidosis": "An acquired metabolic disease that has_material_basis_in low pH in body tissues and blood accompanied by the buildup of lactate especially D-lactate.",
    "larynx cancer": "A respiratory system cancer that is located_in the larynx.",
    "leiomyosarcoma": "A malignant smooth muscle cancer that can arise almost anywhere in the body, but is most common in the uterus, abdomen, or pelvis.",
    "lipid metabolism disorder": "An inherited metabolic disorder that involves the creation and degradation of lipids.",
    "lung adenocarcinoma": "A non-small cell lung carcinoma that derives_from epithelial cells of glandular origin.",
    "lung disease": "A lower respiratory tract disease in which the function of the lungs is adversely affected by narrowing or blockage of the airways resulting in poor air flow, a loss of elasticity in the lungs that produces a decrease in the total volume of air that the lungs are able to hold, and clotting, scarring, or inflammation of the blood vessels that affect the ability of the lungs to take up oxygen and to release carbon dioxide.",
    "lymphoma": "A hematologic cancer that affects lymphocytes that reside in the lymphatic system and in blood-forming organs.",
    "lysosomal storage disease": "An inherited metabolic disorder that involve an abnormal accumulation of substances inside the lysosome resulting from defects in lysosomal function.",
    "maturity-onset diabetes of the young": "A genetic disease that has_material_basis_in mutations in the MODY genes disrupting insulin production.",
    "melanoma": "A cell type cancer that has_material_basis_in abnormally proliferating cells derived_from melanocytes which are found in skin, the bowel and the eye.",
    "methylmalonic acidemia": "An organic acidemia that involves an accumulation of methylmalonic acid in the blood.",
    "methylmalonic aciduria and homocystinuria type cblC": "A methylmalonic acidemia that has_material_basis_in deficiency in synthesis of both AdoCbl and MeCbl (cblC) and is characterized by decreased levels of the coenzymes adenosylcobalamin (AdoCbl) and methylcobalamin (MeCbl), which results in decreased activity of the respective enzymes methylmalonyl-CoA mutase.",
    "methylmalonic aciduria and homocystinuria type cblD": "A methylmalonic aciduria that is characterized by combined homocystinuria and methylmalonic aciduria and deficiency of MCM and MS activities.",
    "methylmalonic aciduria and homocystinuria type cblF": "A methylmalonic acidemia that is characterized by the accumulation of cobalamin in lysosomes which is then unable to synthesize the cofactors adenosylcobalamin (AdoCbl) and methylcobalamin (MeCbl).",
    "migraine": "A brain disease that is characterized by moderate to severe headaches, nausea, extreme sensitivity to light and sound and intense unilaterial throbbing or pulsing.",
    "mucopolysaccharidosis": "A lysosomal storage disease that involves he accumulation of glycosaminoglycans in the tissues and their excretion in the urine.",
    "multiple myeloma": "A myeloma that is located_in the plasma cells in bone marrow.",
    "myelodysplastic myeloproliferative cancer": "A bone marrow cancer that is located_in the bone marrow and results_in the production of too many white blood cells. The cancer possess both dysplastic and proliferative features but are not properly classified as either.",
    "myeloma": "A bone marrow cancer that affects plasma cells in which abnormal plasma cells multiply uncontrollably in the bone marrow and occasionally in other parts of the body.",
    "myocardial infarction": "A coronary artery disease characterized by myocardial cell death (myocardial necrosis) due to prolonged ischaemia.",
    "myopathy": "A muscular disease in which the muscle fibers do not function resulting in muscular weakness.",
    "myotonic disease": "A muscular dystrophy that is characterized by progressive muscle wasting and weakness.",
    "nephroblastoma": "A kidney cancer that affects the kidneys and typically located_in children.",
    "neurodegenerative disease": "A central nervous system disease that results_in the progressive deterioration of function or structure of neurons.",
    "neuropathy": "A nervous system disease that is located_in nerves or nerve cells.",
    "newborn respiratory distress syndrome": "A respiratory failure that is characterized by deficiency of the surfactant coating the inner surface of the lungs, by failure of the lungs to expand and contract properly during breathing with resulting collapse, and by the accumulation of a protein-containing film lining the alveoli and their ducts.",
    "ocular hypertension": "An eye disease that is characterized by elevated intraocular pressure in the absence of optic nerve damage or visual field loss.",
    "oral cavity cancer": "A gastrointestinal system cancer that is located_in the oral cavity.",
    "osteochondrodysplasia": "A bone development disease that results_in defective development of located_in cartilage or located_in bone.",
    "pancreatic cancer": "An endocrine gland cancer located_in the pancreas.",
    "papillary carcinoma": "A carcinoma that is derived_from epithelial cells with finger like projections.",
    "parathyroid carcinoma": "An endocrine gland cancer located_in the parathyroid glands located in the neck.",
    "penis carcinoma": "A penile cancer that is located_in the skin or tissues of the penis.",
    "peripheral neuropathy": "A neuropathy that is located_in nerves of the peripheral nervous system.",
    "pervasive developmental disorder": "A developmental disorder of mental health that refers to a group of five disorders characterized by impairments in socialization and communication, as well as restricted interests and repetitive behaviors.",
    "pharynx cancer": "A gastrointestinal system cancer that is located_in the pharyx.",
    "phenylketonuria": "An amino acid metabolic disorder that is characterized by a mutation in the gene for the hepatic enzyme phenylalanine hydroxylase (PAH), rendering it nonfunctional.",
    "pilocytic astrocytoma": "An astrocytoma that is characterized by cells that look like fibers when viewed under a microscope and is located_in the brain.",
    "pituitary cancer": "An endocrine gland cancer located_in the pituitary gland located at the base of the brain.",
    "postural orthostatic tachycardia syndrome": "A heart conduction disease characterized by orthostatic intolerance that has_material_basis_in heterozygous mutation in the SLC6A2 gene on chromosome 16q12.2.",
    "primary bacterial infectious disease": "A bacterial infectious disease that results_in infection by bacteria as a result of their presence or activity within the normal, healthy host, and their intrinsic virulence is, in part, a necessary consequence of their need to reproduce and spread.",
    "primary immunodeficiency disease": "An immune system disease that results when one or more essential parts of the immune system is missing or not working properly at birth due to a genetic mutation.",
    "primary sclerosing cholangitis": "A sclerosing cholangitis characterized by fibroobliterative inflammation of the biliary tract, leading to cirrhosis and portal hypertension.",
    "pseudoxanthoma elasticum": "An autosomal recessive disease characterized by the accumulation of deposits of calcium and other minerals in elastic fibers, which are a component of connective tissue, this can result in changes in the skin, eyes, cardiovascular system and gastrointestinal system.",
    "ptosis": "An eye disease characterized by the drooping or falling of the upper or lower eyelid.",
    "pulmonary alveolar proteinosis": "A lung disease that is characterized by abnormal accumulation of surfactant occurs within the alveoli, interfering with gas exchange.",
    "pulmonary embolism": "An artery disease characterized by a blockage of the main artery of the lung or one of its branches by a substance that has travelled from elsewhere in the body, e.g. a blood clot.",
    "renal clear cell carcinoma": "A renal cell carcinoma that is the most common type of renal cell carcinoma. The cancerous cells appear very pale or clear when examined under microscope. This cancer can be effectively treated with surgery if the tumor is confined to the kidney.",
    "renal tubular acidosis": "A renal tubular transport disease characterized_by excess levels of acid in the blood, due to a failure of the kidneys to appropriately acidify the urine.",
    "retinoblastoma": "A retinal cell cancer and malignant neoplasm of retina and neuroblastoma and neuroendocrine tumors that derives_from the tissues of the retina.",
    "rhabdomyosarcoma": "A myosarcoma that arise from skeletal muscle progenitors.",
    "rickets": "A bone remodeling disease that has_material_basis_in a vitamin D deficiency in children which results_in softening and deformity located_in bone.",
    "schizophrenia": "A psychotic disorder that is characterized by a disintegration of thought processes and of emotional responsiveness.",
    "secretory diarrhea": "Secretory diarrhea is a diarrhea where there is an increase in the active secretion, or there is an inhibition of absorption causing little to no structural damage. The most common cause of this type of diarrhea is a cholera toxin that stimulates the secretion of anions, especially chloride ions.",
    "severe combined immunodeficiency": "A combined T cell and B cell immunodeficiency that is caused by a defect in several genes encoding for B and T lymphocytes resulting in individuals with non-functional immune systems.",
    "short QT syndrome": "A heart conduction disease that is characterized by heart arrhythmia defined as a short QT interval on an EKG (less than 300 ms) that does not significantly change with heart rate, tall and peaked T waves, and a structurally normal heart.",
    "skin melanoma": "A skin cancer that has_material_basis_in melanocytes.",
    "small intestine carcinoma": "A carcinoma that is located_in the small intestine.",
    "spondylocostal dysostosis": "A dysostosis that results_in abnormal development located_in vertebrae or located_in ribs. The bones of the spine do not develop properly, which causes them to be misshapen and abnormally joined together.",
    "spondyloepimetaphyseal dysplasia": "An osteochondrodysplasia that results_in abnormalities of the located_in vertebral column, located_in epiphysis, located_in metaphysis.",
    "steroid inherited metabolic disorder": "An inherited metabolic disorder that involves defects in steroid metabolism.",
    "stomach cancer": "A gastrointestinal system cancer that is located_in the stomach.",
    "subacute leukemia": "A leukemia that is in between acute and chronic leukemia and is characterized by a moderate duration or severity.",
    "syndactyly": "A synostosis that results_in the fusion of two or more digits.",
    "syndrome": "A disease comprised of a group of signs and symptoms that occur together and characterize a particular abnormality.",
    "syndromic intellectual disability": "An intellectual disability that is characterized by the presence of associated medical and behavioral sign and symptoms.",
    "systemic primary carnitine deficiency disease": "An amino acid metabolic disorder that involves defective proteins called carnitine transporters, which bring carnitine into cells and prevent its escape from the body preventing the body cannot utilize fats for energy.",
    "tetanus": "A primary bacterial infectious disease that results_in prolonged contraction of skeletal muscle fibers, has_material_basis_in Clostridium tetani, which produces tetanospasmin, a neurotoxin, which is carried to the brain and spinal cord, where it binds irreversibly to receptors inhibiting neurotransmission. Damaged upper motor neurons cannot control reflex responses to afferent sensory stimuli.",
    "thanatophoric dysplasia": "An osteochondrodysplasia that results_in short arms and legs with excess folds of skin.",
    "thrombosis": "A vascular disease caused by the formation of a blood clot inside a blood vessel, obstructing the flow of blood through the circulatory system.",
    "thymus cancer": "An immune system cancer located_in the thymus.",
    "thyroid cancer": "An endocrine gland cancer located_in the thryoid gland located in the neck below the thyroid cartilage.",
    "thyroid carcinoma": "A thyroid cancer that has_material_basis_in epithelial cells.",
    "tuberculosis": "A primary bacterial infectious disease that is located_in lungs, located_in lymph nodes, located_in pericardium, located_in brain, located_in pleura and located_in gastrointestinal tract, has_material_basis_in Mycobacterium tuberculosis, which is transmitted_by droplets released into the air when an infected person coughs or sneezes.",
    "urinary system disease": "A disease of anatomical entity that is located_in kidney, ureter, bladder and urethra.",
    "viral infectious disease": "A disease by infectious agent that results_in infection, has_material_basis_in Viruses.",
    "vitamin B12 deficiency": "A vitamin metabolic disorder that results from low blood levels of vitamin B12.",
    "vitamin metabolic disorder": "An inherited metabolic disorder resulting from a deficiency in vitamin or vitamin cofactor transport or metabolism.",
}

# Copyright (C) 2018-2019, DV Klopfenstein. All rights reserved.
